@@ -8,16 +8,16 @@ use Code::TidyAll::CacheModel;
 use Code::TidyAll::Config::INI::Reader;
 use Code::TidyAll::Plugin;
 use Code::TidyAll::Result;
-use Code::TidyAll::Util qw(can_load);
 use Data::Dumper;
 use Date::Format;
 use Digest::SHA qw(sha1_hex);
 use File::Find qw(find);
-use File::Zglob;
+use File::Zglob qw(zglob);
 use List::SomeUtils qw(uniq);
+use Module::Runtime qw( use_module );
 use Path::Tiny qw(path);
 use Scalar::Util qw(blessed);
-use Specio 0.30;
+use Specio 0.40;
 use Specio::Declare;
 use Specio::Library::Builtins;
 use Specio::Library::Numeric;
@@ -28,149 +28,179 @@ use Try::Tiny;
 
 use Moo 2.000000;
 
-our $VERSION = '0.55';
+our $VERSION = '0.67';
 
 sub default_conf_names { ( 'tidyall.ini', '.tidyallrc' ) }
 
 # External
-has 'backup_ttl' => (
+has backup_ttl => (
     is      => 'ro',
     isa     => t('NonEmptyStr'),
     default => '1 hour',
 );
 
-has 'cache' => (
+has cache => (
     is  => 'lazy',
     isa => object_can_type( methods => [qw( get set )] ),
 );
 
-has 'cache_model_class' => (
+has cache_model_class => (
     is      => 'ro',
     isa     => t('ClassName'),
     default => 'Code::TidyAll::CacheModel',
 );
 
-has 'check_only' => (
+has check_only => (
     is  => 'ro',
     isa => t('Bool'),
 );
 
-has 'data_dir' => (
+has data_dir => (
     is     => 'lazy',
     isa    => t('Path'),
     coerce => t('Path')->coercion_sub,
 );
 
-has 'iterations' => (
+has iterations => (
     is      => 'ro',
     isa     => t('PositiveInt'),
     default => 1,
 );
 
-has 'jobs' => (
+has jobs => (
     is      => 'ro',
     isa     => t('Int'),
     default => 1,
 );
 
-has 'list_only' => (
+has list_only => (
     is  => 'ro',
     isa => t('Bool'),
 );
 
-has 'mode' => (
+has mode => (
     is      => 'ro',
     isa     => t('NonEmptyStr'),
     default => 'cli',
 );
 
-has 'msg_outputter' => (
+has msg_outputter => (
     is      => 'ro',
     isa     => t('CodeRef'),
     builder => '_build_msg_outputter',
 );
 
-has 'no_backups' => (
+has no_backups => (
     is  => 'ro',
     isa => t('Bool'),
 );
 
-has 'no_cache' => (
+has no_cache => (
     is  => 'ro',
     isa => t('Bool'),
 );
 
-has 'output_suffix' => (
+has output_suffix => (
     is      => 'ro',
     isa     => t('Str'),
     default => q{},
 );
 
-has 'plugins' => (
+has plugins => (
     is       => 'ro',
-    ias      => t('HashRef'),
+    isa      => t('HashRef'),
     required => 1,
 );
 
-has 'quiet' => (
+has selected_plugins => (
+    is   => 'ro',
+    isa  => t( 'ArrayRef', of => t('NonEmptyStr') ),
+    lazy => 1,
+    default => sub { [] },
+);
+
+has quiet => (
     is  => 'ro',
     isa => t('Bool'),
 );
-has 'recursive' => (
+has recursive => (
     is  => 'ro',
     isa => t('Bool'),
 );
 
-has 'refresh_cache' => (
+has refresh_cache => (
     is  => 'ro',
     isa => t('Bool'),
 );
 
-has 'root_dir' => (
+has root_dir => (
     is       => 'ro',
-    isa      => t('RealDir')->_subify,
+    isa      => t('RealDir'),
     coerce   => t('RealDir')->coercion_sub,
     required => 1
 );
 
-has 'verbose' => (
+has verbose => (
     is      => 'ro',
     isa     => t('Bool'),
     default => 0,
 );
 
-# Internal
-has 'backup_dir' => (
-    is       => 'lazy',
+has inc => (
+    is  => 'ro',
+    isa => t( 'ArrayRef', of => t('NonEmptyStr') ),
+    default => sub { [] },
+);
+
+has _backup_dir => (
+    is       => 'ro',
     isa      => t('Path'),
     init_arg => undef,
+    lazy     => 1,
+    builder  => '_build_backup_dir',
 );
 
-has 'backup_ttl_secs' => (
-    is       => 'lazy',
+has _backup_ttl_secs => (
+    is       => 'ro',
     isa      => t('Int'),
     init_arg => undef,
+    lazy     => 1,
+    builder  => '_build_backup_ttl_secs',
 );
 
-has 'base_sig' => (
-    is       => 'lazy',
+has _base_sig => (
+    is       => 'ro',
     isa      => t('NonEmptyStr'),
     init_arg => undef,
+    lazy     => 1,
+    builder  => '_build_base_sig',
 );
 
-has 'plugin_objects' => (
-    is       => 'lazy',
+has _plugin_objects => (
+    is       => 'ro',
     isa      => t( 'ArrayRef', of => object_isa_type('Code::TidyAll::Plugin') ),
     init_arg => undef,
+    lazy     => 1,
+    builder  => '_build_plugin_objects',
 );
 
-has 'plugins_for_mode' => (
-    is       => 'lazy',
+has _plugins_to_run => (
+    is       => 'ro',
     isa      => t( 'HashRef', of => t('HashRef') ),
     init_arg => undef,
+    lazy     => 1,
+    builder  => '_build_plugins_to_run',
 );
 
-with 'Code::TidyAll::Role::Tempdir';
+has _plugins_for_path => (
+    is       => 'ro',
+    isa      => t( 'HashRef', of => t('HashRef') ),
+    init_arg => undef,
+    lazy     => 1,
+    default => sub { {} },
+);
+
+with qw( Code::TidyAll::Role::HasIgnore Code::TidyAll::Role::Tempdir );
 
 sub _build_backup_dir {
     my $self = shift;
@@ -184,10 +214,15 @@ sub _build_backup_ttl_secs {
 
 sub _build_base_sig {
     my $self = shift;
-    my $active_plugins = join( "|", map { $_->name } @{ $self->plugin_objects } );
+    my $active_plugins = join( q{|}, map { $_->name } @{ $self->_plugin_objects } );
     return $self->_sig( [ $Code::TidyAll::VERSION || 0, $active_plugins ] );
 }
 
+sub _sig {
+    my ( $self, $data ) = @_;
+    return sha1_hex( join( ',', @$data ) );
+}
+
 sub _build_cache {
     my $self = shift;
     return Code::TidyAll::Cache->new( cache_dir => $self->data_dir->child('cache') );
@@ -198,119 +233,51 @@ sub _build_data_dir {
     return $self->root_dir->child('/.tidyall.d');
 }
 
-sub _build_plugins_for_mode {
-    my $self    = shift;
-    my $plugins = $self->plugins;
-    if ( my $mode = $self->mode ) {
-        $plugins = {
-            map { ( $_, $plugins->{$_} ) }
-            grep { $self->_plugin_conf_matches_mode( $plugins->{$_}, $mode ) } keys(%$plugins)
-        };
+sub _build_plugins_to_run {
+    my $self = shift;
+
+    my $all_plugins = $self->plugins;
+    my %selected = map { $_ => 1 } @{ $self->selected_plugins };
+    my %plugins;
+
+    if (%selected) {
+        my @unknown = sort grep { !$all_plugins->{$_} } keys %selected;
+        die "Asked for unknown plugins: [@unknown]" if @unknown;
+        %plugins = map { $_ => $all_plugins->{$_} } keys %selected;
     }
-    return $plugins;
+    elsif ( my $mode = $self->mode ) {
+        %plugins = map { $_ => $all_plugins->{$_} }
+            grep { $self->_plugin_conf_matches_mode( $all_plugins->{$_}, $mode ) }
+            keys %{$all_plugins};
+    }
+
+    return \%plugins;
+}
+
+sub _plugin_conf_matches_mode {
+    my ( $self, $conf, $mode ) = @_;
+
+    if ( my $only_modes = $conf->{only_modes} ) {
+        return 0 if ( q{ } . $only_modes . q{ } ) !~ / $mode /;
+    }
+    if ( my $except_modes = $conf->{except_modes} ) {
+        return 0 if ( q{ } . $except_modes . q{ } ) =~ / $mode /;
+    }
+    return 1;
 }
 
 sub _build_plugin_objects {
     my $self = shift;
-    my @plugin_objects = map { $self->_load_plugin( $_, $self->plugins->{$_} ) }
-        keys( %{ $self->plugins_for_mode } );
 
     # Sort tidiers by weight (by default validators have a weight of 60 and non-
     # validators a weight of 50 meaning non-validators normally go first), then
     # alphabetical
     # TODO: These should probably sort in a consistent way independent of locale
-    return [ sort { ( $a->weight <=> $b->weight ) || ( $a->name cmp $b->name ) } @plugin_objects ];
-}
-
-sub BUILD {
-    my ( $self, $params ) = @_;
-
-    # Strict constructor
-    #
-    if ( my @bad_params = grep { !$self->can($_) } keys(%$params) ) {
-        die sprintf(
-            "unknown constructor param%s %s for %s",
-            @bad_params > 1 ? "s" : "",
-            join( ", ", sort map {"'$_'"} @bad_params ),
-            ref($self)
-        );
-    }
-
-    $self->{plugins_for_path} = {};
-
-    unless ( $self->no_backups ) {
-        $self->backup_dir->mkpath( { mode => 0775 } );
-        $self->_purge_backups_periodically();
-    }
-}
-
-sub new_from_conf_file {
-    my ( $class, $conf_file, %params ) = @_;
-
-    $conf_file = path($conf_file);
-
-    die "no such file '$conf_file'" unless $conf_file->is_file;
-    my $conf_params = $class->_read_conf_file($conf_file);
-    my $main_params = delete( $conf_params->{'_'} ) || {};
-    %params = (
-        plugins  => $conf_params,
-        root_dir => path($conf_file)->realpath->parent,
-        %$main_params, %params
-    );
-
-    # Initialize with alternate class if given
-    #
-    if ( my $tidyall_class = delete( $params{tidyall_class} ) ) {
-        die "cannot load '$tidyall_class'" unless can_load($tidyall_class);
-        $class = $tidyall_class;
-    }
-
-    if ( $params{verbose} ) {
-        my $msg_outputter = $params{msg_outputter} || $class->_build_msg_outputter();
-        $msg_outputter->(
-            "constructing %s with these params: %s", $class,
-            _dump_params( \%params )
-        );
-    }
-
-    return $class->new(%params);
-}
-
-sub _dump_params {
-    my $p = shift;
-
-    return Data::Dumper->new( [ _recurse_dump($p) ] )->Indent(0)->Sortkeys(1)->Quotekeys(0)
-        ->Terse(1)->Dump;
-}
-
-# This is all ridiculous workaround the fact that there is no good way to tell
-# Data::Dumper how to serialize a Path::Tiny object.
-sub _recurse_dump {
-    my ($p) = @_;
-
-    my %dump;
-    for my $k ( keys %{$p} ) {
-        my $v = $p->{$k};
-        if ( blessed $v ) {
-            if ( $v->isa('Path::Tiny') ) {
-                $dump{$k} = $v . q{};
-            }
-            else {
-                die 'Cannot dump ' . ref($v) . ' object';
-            }
-        }
-        elsif ( ref $v eq 'HASH' ) {
-            $dump{$k} = _recurse_dump( $p->{$v} );
-        }
-        elsif ( ref $v eq 'ARRAY' ) {
-            $dump{$k} = [ map { _recurse_dump($_) } @{ $p->{$v} } ];
-        }
-        else {
-            $dump{$k} = $v;
-        }
-    }
-
-    return \%dump;
+    return [
+        sort { ( $a->weight <=> $b->weight ) || ( $a->name cmp $b->name ) }
+            map { $self->_load_plugin( $_, $self->_plugins_to_run->{$_} ) }
+            keys %{ $self->_plugins_to_run }
+    ];
 }
 
 sub _load_plugin {
@@ -326,30 +293,168 @@ sub _load_plugin {
         : "Code::TidyAll::Plugin::$plugin_fname"
     );
     try {
-        can_load($plugin_class) || die "not found";
+        use_module($plugin_class) || die 'not found';
     }
     catch {
-        die "could not load plugin class '$plugin_class': $_";
+        die qq{could not load plugin class '$plugin_class': $_};
     };
 
     return $plugin_class->new(
-        class   => $plugin_class,
         name    => $plugin_name,
         tidyall => $self,
         %$plugin_conf
     );
 }
 
-sub _plugin_conf_matches_mode {
-    my ( $self, $conf, $mode ) = @_;
+sub BUILD {
+    my ( $self, $params ) = @_;
 
-    if ( my $only_modes = $conf->{only_modes} ) {
-        return 0 if ( " " . $only_modes . " " ) !~ / $mode /;
+    # Strict constructor
+    #
+    if ( my @bad_params = grep { !$self->can($_) } keys(%$params) ) {
+        die sprintf(
+            'unknown constructor param%s %s for %s',
+            @bad_params > 1 ? 's' : q{},
+            join( ', ', sort map {qq['$_']} @bad_params ),
+            ref($self)
+        );
     }
-    if ( my $except_modes = $conf->{except_modes} ) {
-        return 0 if ( " " . $except_modes . " " ) =~ / $mode /;
+
+    unless ( $self->no_backups ) {
+        $self->_backup_dir->mkpath( { mode => 0775 } );
+        $self->_purge_backups_periodically();
     }
-    return 1;
+
+    @INC = ( @{ $self->inc }, @INC );
+}
+
+sub _purge_backups_periodically {
+    my ($self) = @_;
+    my $cache = $self->cache;
+    my $last_purge_backups = $cache->get('last_purge_backups') || 0;
+    if ( time > $last_purge_backups + $self->_backup_ttl_secs ) {
+        $self->_purge_backups();
+        $cache->set( 'last_purge_backups', time() );
+    }
+}
+
+sub _purge_backups {
+    my ($self) = @_;
+    $self->msg('purging old backups') if $self->verbose;
+    find(
+        {
+            follow => 0,
+            wanted => sub {
+                unlink $_ if -f && /\.bak$/ && time > ( stat($_) )[9] + $self->_backup_ttl_secs;
+            },
+            no_chdir => 1
+        },
+        $self->_backup_dir,
+    );
+}
+
+sub new_from_conf_file {
+    my ( $class, $conf_file, %params ) = @_;
+
+    $conf_file = path($conf_file);
+
+    die qq{no such file '$conf_file'} unless $conf_file->is_file;
+    my $conf_params = $class->_read_conf_file($conf_file);
+    my $main_params = delete( $conf_params->{'_'} ) || {};
+
+    %params = (
+        plugins  => $conf_params,
+        root_dir => path($conf_file)->realpath->parent,
+        %{$main_params},
+        %params
+    );
+
+    # Initialize with alternate class if given
+    #
+    if ( my $tidyall_class = delete( $params{tidyall_class} ) ) {
+        local @INC = ( @{ $conf_params->{inc} }, @INC ) if $conf_params->{inc};
+        use_module($tidyall_class) or die qq{cannot load '$tidyall_class'};
+        $class = $tidyall_class;
+    }
+
+    if ( $params{verbose} ) {
+        my $msg_outputter = $params{msg_outputter} || $class->_build_msg_outputter();
+        $msg_outputter->(
+            'constructing %s with these params: %s', $class,
+            _dump_params( \%params )
+        );
+    }
+
+    return $class->new(%params);
+}
+
+sub _read_conf_file {
+    my ( $class, $conf_file ) = @_;
+    my $conf_string = $conf_file->slurp_utf8;
+    my $root_dir    = $conf_file->parent;
+    $conf_string =~ s/\$ROOT/$root_dir/g;
+    my $conf_hash = Code::TidyAll::Config::INI::Reader->read_string($conf_string);
+    die qq{'$conf_file' did not evaluate to a hash}
+        unless ( ref($conf_hash) eq 'HASH' );
+    return $conf_hash;
+}
+
+sub _dump_params {
+    my $p = shift;
+
+    return Data::Dumper->new( [ _recurse_dump($p) ] )->Indent(0)->Sortkeys(1)->Quotekeys(0)
+        ->Terse(1)->Dump;
+}
+
+# This is all a ridiculous workaround around the fact that there is no good
+# way to tell Data::Dumper how to serialize a Path::Tiny object.
+sub _recurse_dump {
+    my ($p) = @_;
+
+    if ( ref $p eq 'HASH' ) {
+        my %dump;
+        for my $k ( keys %{$p} ) {
+            my $v = $p->{$k};
+            if ( blessed $v ) {
+                if ( $v->isa('Path::Tiny') ) {
+                    $dump{$k} = $v . q{};
+                }
+                else {
+                    die 'Cannot dump ' . ref($v) . ' object';
+                }
+            }
+            elsif ( ref $v =~ /^(?:HASH|ARRAY)$/ ) {
+                $dump{$k} = _recurse_dump($v);
+            }
+            else {
+                $dump{$k} = $v;
+            }
+        }
+        return \%dump;
+    }
+    elsif ( ref $p eq 'ARRAY' ) {
+        my @dump;
+        for my $v ( @{$p} ) {
+            if ( blessed $v ) {
+                if ( $v->isa('Path::Tiny') ) {
+                    push @dump, $v . q{};
+                }
+                else {
+                    die 'Cannot dump ' . ref($v) . ' object';
+                }
+            }
+            elsif ( ref $v =~ /^(?:HASH|ARRAY)$/ ) {
+                push @dump, _recurse_dump($v);
+            }
+            else {
+                push @dump, $v;
+            }
+        }
+        return \@dump;
+    }
+
+    return;
+    die '_recurse_dump was called with a value that is neither a hashref nor an arrayref';
 }
 
 sub process_all {
@@ -442,7 +547,7 @@ sub process_file {
 
     if ( $self->list_only ) {
         if ( my @plugins = $self->plugins_for_path($path) ) {
-            $self->msg( "%s (%s)", $path, join( ", ", map { $_->name } @plugins ) );
+            $self->msg( '%s (%s)', $path, join( ', ', map { $_->name } @plugins ) );
         }
         return Code::TidyAll::Result->new( path => $path, state => 'checked' );
     }
@@ -452,7 +557,7 @@ sub process_file {
         $cache_model->remove;
     }
     elsif ( $cache_model->is_cached ) {
-        $self->msg( "[cached] %s", $path ) if $self->verbose;
+        $self->msg( '[cached] %s', $path ) if $self->verbose;
         return Code::TidyAll::Result->new( path => $path, state => 'cached' );
     }
 
@@ -479,31 +584,64 @@ sub process_file {
     return $result;
 }
 
+sub _small_path {
+    my ( $self, $path ) = @_;
+    die sprintf( q{'%s' is not underneath root dir '%s'!}, $path, $self->root_dir )
+        unless index( $path, $self->root_dir ) == 0;
+    return path( substr( $path . q{}, length( $self->root_dir ) + 1 ) );
+}
+
+sub plugins_for_path {
+    my ( $self, $path ) = @_;
+
+    $self->_plugins_for_path->{$path}
+        ||= [ grep { $_->matches_path($path) } @{ $self->_plugin_objects } ];
+    return @{ $self->_plugins_for_path->{$path} };
+}
+
 sub _cache_model_for {
     my ( $self, $path, $full_path ) = @_;
     return $self->cache_model_class->new(
-        path         => $path,
-        full_path    => $full_path,
-        cache_engine => $self->no_cache ? undef : $self->cache,
-        base_sig     => $self->base_sig,
+        path      => $path,
+        full_path => $full_path,
+        ( $self->no_cache ? () : ( cache_engine => $self->cache ) ),
+        base_sig => $self->_base_sig,
     );
 }
 
+sub _backup_file {
+    my ( $self, $path, $contents ) = @_;
+    unless ( $self->no_backups ) {
+        my $backup_file = $self->_backup_dir->child( $self->_backup_filename($path) );
+        $backup_file->parent->mkpath( { mode => 0775 } );
+        $backup_file->spew($contents);
+    }
+}
+
+sub _backup_filename {
+    my ( $self, $path ) = @_;
+
+    return join( q{}, $path, '-', time2str( '%Y%m%d-%H%M%S', time ), '.bak' );
+}
+
 sub process_source {
     my ( $self, $contents, $path ) = @_;
 
-    die "contents and path required" unless defined($contents) && defined($path);
+    $path = path($path);
+
+    die 'contents and path required' unless defined($contents) && defined($path);
     my @plugins = $self->plugins_for_path($path);
+
     if ( !@plugins ) {
         $self->msg(
-            "[no plugins apply%s] %s",
-            $self->mode ? " for mode '" . $self->mode . "'" : "", $path
+            '[no plugins apply%s] %s',
+            $self->mode ? q{ for mode '} . $self->mode . q{'} : q{}, $path
         ) if $self->verbose;
         return Code::TidyAll::Result->new( path => $path, state => 'no_match' );
     }
 
     if ( $self->verbose ) {
-        my @names = map { $_->name } @plugins;
+        my @names = join ', ', map { $_->name } @plugins;
         $self->msg("[applying the following plugins: @names]");
     }
 
@@ -526,12 +664,12 @@ sub process_source {
     catch {
         chomp;
         $error = $_;
-        $error = sprintf( "*** '%s': %s", $plugin->name, $_ ) if $plugin;
+        $error = sprintf( q{*** '%s': %s}, $plugin->name, $_ ) if $plugin;
     };
 
     my $was_tidied = !$error && ( $new_contents ne $orig_contents );
     if ( $was_tidied && $self->check_only ) {
-        $error = "*** needs tidying";
+        $error = '*** needs tidying';
         foreach my $diff (@diffs) {
             $error .= "\n\n";
             $error .= "$diff->[0] made the following change:\n$diff->[1]";
@@ -541,10 +679,10 @@ sub process_source {
     }
 
     if ( !$self->quiet || $error ) {
-        my $status = $was_tidied ? "[tidied]  " : "[checked] ";
+        my $status = $was_tidied ? '[tidied]  ' : '[checked] ';
         my $plugin_names
-            = $self->verbose ? sprintf( " (%s)", join( ", ", map { $_->name } @plugins ) ) : "";
-        $self->msg( "%s%s%s", $status, $path, $plugin_names );
+            = $self->verbose ? sprintf( ' (%s)', join( ', ', map { $_->name } @plugins ) ) : q{};
+        $self->msg( '%s%s%s', $status, $path, $plugin_names );
     }
 
     if ($error) {
@@ -563,54 +701,23 @@ sub process_source {
     }
 }
 
-sub _read_conf_file {
-    my ( $class, $conf_file ) = @_;
-    my $conf_string = $conf_file->slurp_utf8;
-    my $root_dir    = $conf_file->parent;
-    $conf_string =~ s/\$ROOT/$root_dir/g;
-    my $conf_hash = Code::TidyAll::Config::INI::Reader->read_string($conf_string);
-    die "'$conf_file' did not evaluate to a hash"
-        unless ( ref($conf_hash) eq 'HASH' );
-    return $conf_hash;
-}
-
-sub _backup_file {
-    my ( $self, $path, $contents ) = @_;
-    unless ( $self->no_backups ) {
-        my $backup_file = $self->backup_dir->child( $self->_backup_filename($path) );
-        $backup_file->parent->mkpath( { mode => 0775 } );
-        $backup_file->spew($contents);
-    }
-}
-
-sub _backup_filename {
-    my ( $self, $path ) = @_;
-
-    return join( q{}, $path, '-', time2str( "%Y%m%d-%H%M%S", time ), '.bak' );
-}
-
-sub _purge_backups_periodically {
-    my ($self) = @_;
-    my $cache = $self->cache;
-    my $last_purge_backups = $cache->get("last_purge_backups") || 0;
-    if ( time > $last_purge_backups + $self->backup_ttl_secs ) {
-        $self->_purge_backups();
-        $cache->set( "last_purge_backups", time() );
-    }
-}
-
-sub _purge_backups {
-    my ($self) = @_;
-    $self->msg("purging old backups") if $self->verbose;
-    find(
-        {
-            follow => 0,
-            wanted => sub {
-                unlink $_ if -f && /\.bak$/ && time > ( stat($_) )[9] + $self->backup_ttl_secs;
-            },
-            no_chdir => 1
-        },
-        $self->backup_dir
+sub _error_result {
+    my ( $self, $msg, $path, $orig_contents, $new_contents ) = @_;
+    $self->msg( '%s', $msg );
+    return Code::TidyAll::Result->new(
+        path  => $path,
+        state => 'error',
+        error => $msg,
+        (
+              ( defined $orig_contents && length $orig_contents )
+            ? ( orig_contents => $orig_contents )
+            : ()
+        ),
+        (
+              ( defined $new_contents && length $new_contents )
+            ? ( new_contents => $new_contents )
+            : ()
+        ),
     );
 }
 
@@ -624,9 +731,9 @@ sub find_conf_file {
         || $class->_find_conf_file_upward( $conf_names, $path2 );
     unless ( defined $conf_file ) {
         die sprintf(
-            "could not find %s upwards from %s",
-            join( " or ", @$conf_names ),
-            ( $path1 eq $path2 ) ? "'$path1'" : "'$path1' or '$path2'"
+            'could not find %s upwards from %s',
+            join( ' or ', @$conf_names ),
+            ( $path1 eq $path2 ) ? qq{'$path1'} : qq{'$path1' or '$path2'}
         );
     }
     return $conf_file;
@@ -641,53 +748,58 @@ sub _find_conf_file_upward {
             my $try_path = $search_dir->child($conf_name);
             return $try_path if $try_path->is_file;
         }
-        if ( $search_dir eq '/' ) {
-            return undef;
-        }
-        else {
-            $search_dir = $search_dir->parent;
-        }
-        die "inf loop!" if ++$cnt > 100;
+
+        my $parent = $search_dir->parent;
+        last if $parent eq $search_dir;
+        $search_dir = $parent;
+
+        die 'inf loop!' if ++$cnt > 100;
     }
 }
 
 sub find_matched_files {
     my ($self) = @_;
 
-    my @matched_files;
-    my $plugins_for_path = $self->{plugins_for_path};
+    my $plugins_for_path = $self->_plugins_for_path;
     my $root_length      = length( $self->root_dir );
-    foreach my $plugin ( @{ $self->plugin_objects } ) {
-        my @selected = grep { -f && !-l } $self->_zglob( $plugin->selects );
-        if ( @{ $plugin->ignores } ) {
-            my %is_ignored = map { ( $_, 1 ) } $self->_zglob( $plugin->ignores );
-            @selected = grep { !$is_ignored{$_} } @selected;
-        }
-        if ( my $shebang = $plugin->shebang ) {
-            my $re = join '|', map {quotemeta} @{$shebang};
-            $re       = qr/^#!.*\b(?:$re)\b/;
-            @selected = grep {
-                my $fh;
-                open $fh, '<', $_ and <$fh> =~ /$re/;
-            } @selected;
-        }
-        push( @matched_files, @selected );
-        foreach my $file (@selected) {
+
+    my @all;
+    for my $plugin ( @{ $self->_plugin_objects } ) {
+        my @matched = $self->_matched_by_plugin($plugin);
+        push @all, @matched;
+
+        # When we end up in process_source we'll need to know which plugins
+        # match a given file. This could be (re-)calculated When we call
+        # ->plugins_for_path($file) there but since we already know the path
+        # to plugin mapping, we might as well store it here.
+        for my $file (@matched) {
             my $path = substr( $file, $root_length + 1 );
             $plugins_for_path->{$path} ||= [];
-            push( @{ $plugins_for_path->{$path} }, $plugin );
+            push @{ $plugins_for_path->{$path} }, $plugin;
         }
     }
 
-    return map { path($_) } sort( uniq(@matched_files) );
+    return map { path($_) } uniq(@all);
 }
 
-sub plugins_for_path {
-    my ( $self, $path ) = @_;
+sub _matched_by_plugin {
+    my $self   = shift;
+    my $plugin = shift;
 
-    $self->{plugins_for_path}->{$path}
-        ||= [ grep { $_->matches_path($path) } @{ $self->plugin_objects } ];
-    return @{ $self->{plugins_for_path}->{$path} };
+    my %is_ignored = map { $_ => 1 }
+        $self->_zglob( [ @{ $self->ignores || [] }, @{ $plugin->ignores || [] } ] );
+    my @matched = grep { !$is_ignored{$_} } grep { -f && !-l } $self->_zglob( $plugin->selects );
+
+    my $shebang = $plugin->shebang
+        or return @matched;
+
+    my $re = join '|', map {quotemeta} @{$shebang};
+    $re = qr/^#!.*\b(?:$re)\b/;
+    return grep {
+        my $fh;
+        open $fh, '<', $_ or die $!;
+        scalar <$fh> =~ /$re/;
+    } @matched;
 }
 
 sub _zglob {
@@ -697,27 +809,15 @@ sub _zglob {
     my @files;
     foreach my $glob (@$globs) {
         try {
-            push( @files, File::Zglob::zglob( join( "/", $self->root_dir, $glob ) ) );
+            push @files, zglob( join( "/", $self->root_dir, $glob ) );
         }
         catch {
-            die "error parsing '$glob': $_";
+            die qq{error parsing '$glob': $_};
         }
     }
     return uniq(@files);
 }
 
-sub _small_path {
-    my ( $self, $path ) = @_;
-    die sprintf( "'%s' is not underneath root dir '%s'!", $path, $self->root_dir )
-        unless index( $path, $self->root_dir ) == 0;
-    return path( substr( $path . q{}, length( $self->root_dir ) + 1 ) );
-}
-
-sub _sig {
-    my ( $self, $data ) = @_;
-    return sha1_hex( join( ",", @$data ) );
-}
-
 sub msg {
     my ( $self, $format, @params ) = @_;
     $self->msg_outputter()->( $format, @params );
@@ -730,18 +830,6 @@ sub _build_msg_outputter {
     };
 }
 
-sub _error_result {
-    my ( $self, $msg, $path, $orig_contents, $new_contents ) = @_;
-    $self->msg( "%s", $msg );
-    return Code::TidyAll::Result->new(
-        path          => $path,
-        state         => 'error',
-        error         => $msg,
-        orig_contents => $orig_contents,
-        new_contents  => $new_contents,
-    );
-}
-
 1;
 
 # ABSTRACT: Engine for tidyall, your all-in-one code tidier and validator
@@ -758,7 +846,7 @@ Code::TidyAll - Engine for tidyall, your all-in-one code tidier and validator
 
 =head1 VERSION
 
-version 0.55
+version 0.67
 
 =head1 SYNOPSIS
 
@@ -792,17 +880,15 @@ This is the engine used by L<tidyall> - read that first to get an overview.
 
 You can call this API from your own program instead of executing C<tidyall>.
 
-=head1 CONSTRUCTION
+=head1 METHODS
 
-=head2 Constructor methods
+This class offers the following methods:
 
-=over
-
-=item new (%params)
+=head2 Code::TidyAll->new(%params)
 
 The regular constructor. Must pass at least I<plugins> and I<root_dir>.
 
-=item new_with_conf_file ($conf_file, %params)
+=head2 $tidyall->new_with_conf_file( $conf_file, %params )
 
 Takes a conf file path, followed optionally by a set of key/value parameters.
 Reads parameters out of the conf file and combines them with the passed
@@ -811,64 +897,81 @@ parameters (the latter take precedence), and calls the regular constructor.
 If the conf file or params defines I<tidyall_class>, then that class is
 constructed instead of C<Code::TidyAll>.
 
-=back
+=head3 Constructor parameters
 
-=head2 Constructor parameters
+=over 4
 
-=over
-
-=item plugins
+=item * plugins
 
 Specify a hash of plugins, each of which is itself a hash of options. This is
 equivalent to what would be parsed out of the sections in the configuration
 file.
 
-=item cache_model_class
+=item * selected_plugins
+
+An arrayref of plugins to be used. This overrides the C<mode> parameter.
+
+This is really only useful if you're getting configuration from a config file
+and want to narrow the set of plugins to be run.
+
+Note that plugins will still only run on files which match their C<select> and
+C<ignore> configuration.
+
+=item * cache_model_class
 
 The cache model class. Defaults to C<Code::TidyAll::CacheModel>
 
-=item cache
+=item * cache
 
 The cache instance (e.g. an instance of C<Code::TidyAll::Cache> or a C<CHI>
 instance.) An instance of C<Code::TidyAll::Cache> is automatically instantiated
 by default.
 
-=item backup_ttl
+=item * backup_ttl
 
-=item check_only
+=item * check_only
 
 If this is true, then we simply check that files pass validation steps and that
 tidying them does not change the file. Any changes from tidying are not
 actually written back to the file.
 
-=item no_cleanup
+=item * no_cleanup
 
 A boolean indicating if we should skip cleaning temporary files or not.
 Defaults to false.
 
-=item data_dir
+=item * inc
 
-=item iterations
+An arrayref of directories to prepend to C<@INC>. This can be set via the
+command-line as C<-I>, but you can also set it in a config file.
 
-=item mode
+This affects both loading and running plugins.
 
-=item no_backups
+=item * data_dir
 
-=item no_cache
+=item * iterations
 
-=item output_suffix
+=item * mode
 
-=item quiet
+=item * no_backups
 
-=item root_dir
+=item * no_cache
 
-=item verbose
+=item * output_suffix
+
+=item * quiet
+
+=item * root_dir
+
+=item * ignore
+
+=item * verbose
 
 These options are the same as the equivalent C<tidyall> command-line options,
 replacing dashes with underscore (e.g. the C<backup-ttl> option becomes
 C<backup_ttl> here).
 
-=item msg_outputter
+=item * msg_outputter
 
 This is a subroutine reference that is called whenever a message needs to be
 printed in some way. The sub receives a C<sprintf()> format string followed by
@@ -878,74 +981,74 @@ Test::Builder->diag >> method.
 
 =back
 
-=head1 METHODS
+=head2 $tidyall->process_paths( $path, ... )
 
-=over
+This method iterates through a list of paths, processing all the files it
+finds. It will descend into subdirectories if C<recursive> flag is true.
+Returns a list of L<Code::TidyAll::Result> objects, one for each file.
 
-=item process_paths (path, ...)
+=head2 $tidyall->process_file( $file )
 
-Call L</process_file> on each file; descend recursively into each directory if
-the C<recursive> flag is on. Return a list of L<Code::TidyAll::Result> objects,
-one for each file.
+Process the one I<file>, meaning:
 
-=item process_file (file)
-
-Process the I<file>, meaning
-
-=over
+=over 4
 
 =item *
 
-Check the cache and return immediately if file has not changed
+Check the cache and return immediately if file has not changed.
 
 =item *
 
-Apply appropriate matching plugins
+Apply appropriate matching plugins.
 
 =item *
 
-Print success or failure result to STDOUT, depending on quiet/verbose settings
+Print success or failure result to STDOUT, depending on quiet/verbose settings.
 
 =item *
 
-Write the cache if enabled
+Write to the cache if caching is enabled.
 
 =item *
 
-Return a L<Code::TidyAll::Result> object
+Return a L<Code::TidyAll::Result> object.
 
 =back
 
-=item process_source (I<source>, I<path>)
+=head2 $tidyall->process_source( $source, $path )
 
-Like L</process_file>, but process the I<source> string instead of a file, and
-do not read from or write to the cache. You must still pass the relative
+Like C<process_file>, but process the I<source> string instead of a file, and
+does not read from or write to the cache. You must still pass the relative
 I<path> from the root as the second argument, so that we know which plugins to
-apply. Return a L<Code::TidyAll::Result> object.
+apply. Returns a L<Code::TidyAll::Result> object.
 
-=item plugins_for_path (I<path>)
+=head2 $tidyall->plugins_for_path($path)
 
-Given a relative I<path> from the root, return a list of
+Given a relative I<path> from the root, returns a list of
 L<Code::TidyAll::Plugin> objects that apply to it, or an empty list if no
 plugins apply.
 
-=item find_conf_file (I<conf_names>, I<start_dir>)
-
-Class method. Start in the I<start_dir> and work upwards, looking for one of
-the I<conf_names>. Return the pathname if found or throw an error if not found.
-
-=item find_matched_files
+=head2 $tidyall->find_matched_files
 
 Returns a list of sorted files that match at least one plugin in configuration.
 
-=back
+=head2 Code::TidyAll->find_conf_file( $conf_names, $start_dir )
+
+Start in the I<start_dir> and work upwards, looking for a file matching one of
+the I<conf_names>. Returns the pathname if found or throw an error if not
+found.
 
 =head1 SUPPORT
 
-Bugs may be submitted through
+Bugs may be submitted at
 L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
-I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for Code-TidyAll can be found at
+L<https://github.com/houseabsolute/perl-code-tidyall>.
 
 =head1 AUTHORS
 
@@ -963,7 +1066,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Adam Herzog Andy Jack Finn Smith George Hartzell Graham Knop Gregory Oschwald Joe Crotty Mark Fowler Grimes Martin Gruner Mohammad S Anwar Olaf Alders Pedro Melo Ricardo Signes Sergey Romanov timgimyee
+=for stopwords Adam Herzog Andy Jack Finn Smith George Hartzell Graham Knop Gregory Oschwald Joe Crotty Mark Fowler Grimes Martin Gruner Mohammad S Anwar Olaf Alders Pedro Melo Ricardo Signes Sergey Romanov Shlomi Fish timgimyee
 
 =over 4
 
@@ -1029,15 +1132,22 @@ Sergey Romanov <sromanov-dev@yandex.ru>
 
 =item *
 
+Shlomi Fish <shlomif@shlomifish.org>
+
+=item *
+
 timgimyee <tim.gim.yee@gmail.com>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2016 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2017 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under the same
 terms as the Perl 5 programming language system itself.
 
+The full text of the license can be found in the F<LICENSE> file included with
+this distribution.
+
 =cut
