@@ -4,33 +4,26 @@ use strict;
 use warnings;
 
 use IPC::Run3 qw(run3);
+use Text::ParseWords qw(shellwords);
 use Try::Tiny;
 
 use Moo;
 
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.55';
+with 'Code::TidyAll::Role::RunsCommand';
+
+our $VERSION = '0.67';
 
 sub _build_cmd {'js-beautify'}
 
 sub transform_file {
     my ( $self, $file ) = @_;
 
-    try {
-        my $cmd = join( " ", $self->cmd, $self->argv, $file );
+    my $output = $self->_run_or_die( '-f', $file );
+    $file->spew($output);
 
-        my $output;
-        my $exit = run3( $cmd, \undef, \$output, \$output );
-        die "exited with $?\n" if $?;
-        $file->spew($output);
-    }
-    catch {
-        die sprintf(
-            "%s failed - possibly bad arg list '%s'\n    $_", $self->cmd,
-            $self->argv
-        );
-    };
+    return;
 }
 
 1;
@@ -49,7 +42,7 @@ Code::TidyAll::Plugin::JSBeautify - Use js-beautify with tidyall
 
 =head1 VERSION
 
-version 0.55
+version 0.67
 
 =head1 SYNOPSIS
 
@@ -69,28 +62,34 @@ Install L<npm|https://npmjs.org/>, then run
 
     npm install js-beautify -g
 
-Do not confuse this with the C<jsbeautify> package (without the dash).
+Do not confuse this with the C<jsbeautify> command, which is provided by the
+L<JavaScript::Beautifier> module.
 
 =head1 CONFIGURATION
 
-=over
+This plugin accepts the following configuration options:
 
-=item argv
+=head2 argv
 
-Arguments to pass to js-beautify
+Arguments to pass to C<js-beautify>.
 
-=item cmd
+=head2 cmd
 
-Full path to js-beautify
-
-=back
+The path for the C<js-beautify> command. By default this is just
+C<js-beautify>, meaning that the user's C<PATH> will be searched for the
+command.
 
 =head1 SUPPORT
 
-Bugs may be submitted through
+Bugs may be submitted at
 L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
-I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for Code-TidyAll can be found at
+L<https://github.com/houseabsolute/perl-code-tidyall>.
 
 =head1 AUTHORS
 
@@ -108,9 +107,12 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2016 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2017 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under the same
 terms as the Perl 5 programming language system itself.
 
+The full text of the license can be found in the F<LICENSE> file included with
+this distribution.
+
 =cut
