@@ -1,12 +1,17 @@
 package Code::TidyAll::Plugin::MasonTidy;
 
+use strict;
+use warnings;
+
 use Mason::Tidy;
 use Mason::Tidy::App;
-use Moo;
 use Text::ParseWords qw(shellwords);
+
+use Moo;
+
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.32';
+our $VERSION = '0.67';
 
 sub _build_cmd {'masontidy'}
 
@@ -27,13 +32,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Code::TidyAll::Plugin::MasonTidy - Use masontidy with tidyall
 
 =head1 VERSION
 
-version 0.32
+version 0.67
 
 =head1 SYNOPSIS
 
@@ -55,21 +62,23 @@ Install L<masontidy> from CPAN.
 
 =head1 CONFIGURATION
 
-=over
+This plugin accepts the following configuration options:
 
-=item argv
+=head2 argv
 
-Arguments to pass to masontidy
+Arguments to pass to C<masontidy>.
 
-=item cmd
+=head1 SUPPORT
 
-Full path to masontidy
+Bugs may be submitted at
+L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
-=back
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
 
-=head1 SEE ALSO
+=head1 SOURCE
 
-L<Code::TidyAll>
+The source code repository for Code-TidyAll can be found at
+L<https://github.com/houseabsolute/perl-code-tidyall>.
 
 =head1 AUTHORS
 
@@ -87,9 +96,12 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2015 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2017 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under the same
 terms as the Perl 5 programming language system itself.
 
+The full text of the license can be found in the F<LICENSE> file included with
+this distribution.
+
 =cut
