@@ -10,11 +10,18 @@ use Moo;
 
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.55';
+our $VERSION = '0.67';
 
 sub transform_source {
     my ( $self, $source ) = @_;
 
+    # This bit of insanity is needed because if some other code calls
+    # Getopt::Long::Configure() to change some options, then everything can go
+    # to hell. Internally perltidy() tries to use Getopt::Long without
+    # resetting the configuration defaults, leading to very confusing
+    # errors. See https://rt.cpan.org/Ticket/Display.html?id=118558
+    Getopt::Long::ConfigDefaults();
+
     # perltidy reports errors in two different ways.
     # Argument/profile errors are output and an error_flag is returned.
     # Syntax errors are sent to errorfile or stderr, depending on the
@@ -54,7 +61,7 @@ Code::TidyAll::Plugin::PerlTidy - Use perltidy with tidyall
 
 =head1 VERSION
 
-version 0.55
+version 0.67
 
 =head1 SYNOPSIS
 
@@ -84,20 +91,23 @@ Install perltidy from CPAN.
 
 =head1 CONFIGURATION
 
-=over
+This plugin accepts the following configuration options:
 
-=item argv
+=head2 argv
 
-Arguments to pass to perltidy
-
-=back
+Arguments to pass to C<perltidy>.
 
 =head1 SUPPORT
 
-Bugs may be submitted through
+Bugs may be submitted at
 L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
-I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for Code-TidyAll can be found at
+L<https://github.com/houseabsolute/perl-code-tidyall>.
 
 =head1 AUTHORS
 
@@ -115,9 +125,12 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2016 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2017 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under the same
 terms as the Perl 5 programming language system itself.
 
+The full text of the license can be found in the F<LICENSE> file included with
+this distribution.
+
 =cut
