@@ -4,20 +4,24 @@ use strict;
 use warnings;
 
 use Pod::Checker;
+use Specio::Library::Numeric;
 
 use Moo;
 
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.55';
+our $VERSION = '0.67';
 
-has 'warnings' => ( is => 'ro' );
+has warnings => (
+    is  => 'ro',
+    isa => t('PositiveInt'),
+);
 
 sub validate_file {
     my ( $self, $file ) = @_;
 
     my $result;
-    my %options = ( defined( $self->warnings ) ? ( '-warnings' => $self->warnings ) : () );
+    my %options = ( $self->warnings ? ( '-warnings' => $self->warnings ) : () );
     my $checker = Pod::Checker->new(%options);
     my $output;
     open my $fh, '>', \$output;
@@ -43,7 +47,7 @@ Code::TidyAll::Plugin::PodChecker - Use podchecker with tidyall
 
 =head1 VERSION
 
-version 0.55
+version 0.67
 
 =head1 SYNOPSIS
 
@@ -72,21 +76,24 @@ Install podchecker from CPAN.
 
 =head1 CONFIGURATION
 
-=over
+This plugin accepts the following configuration options:
 
-=item warnings
+=head2 warnings
 
-Level of warnings to consider as errors - 1 or 2. By default, warnings will be
-ignored.
-
-=back
+The level of warnings to consider as errors - 1 or 2. By default, warnings will
+be ignored.
 
 =head1 SUPPORT
 
-Bugs may be submitted through
+Bugs may be submitted at
 L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
-I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for Code-TidyAll can be found at
+L<https://github.com/houseabsolute/perl-code-tidyall>.
 
 =head1 AUTHORS
 
@@ -104,9 +111,12 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2016 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2017 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under the same
 terms as the Perl 5 programming language system itself.
 
+The full text of the license can be found in the F<LICENSE> file included with
+this distribution.
+
 =cut
