@@ -7,17 +7,32 @@ use Capture::Tiny qw();
 use IPC::Run3;
 use List::SomeUtils qw(uniq);
 use Pod::Spell;
+use Specio::Library::Builtins;
+use Specio::Library::String;
 use Text::ParseWords qw(shellwords);
 
 use Moo;
 
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.55';
+our $VERSION = '0.67';
 
-has 'ispell_argv' => ( is => 'ro', default => q{} );
-has 'ispell_cmd'  => ( is => 'ro', default => 'ispell' );
-has 'suggest'     => ( is => 'ro' );
+has ispell_argv => (
+    is      => 'ro',
+    isa     => t('Str'),
+    default => q{}
+);
+
+has ispell_cmd => (
+    is      => 'ro',
+    isa     => t('NonEmptyStr'),
+    default => 'ispell'
+);
+
+has suggest => (
+    is  => 'ro',
+    isa => t('Bool'),
+);
 
 sub validate_file {
     my ( $self, $file ) = @_;
@@ -27,10 +42,10 @@ sub validate_file {
     die $error if $error;
 
     my ($output);
-    my @cmd = ( $self->ispell_cmd, shellwords( $self->ispell_argv ), "-a" );
+    my @cmd = ( $self->ispell_cmd, shellwords( $self->ispell_argv ), '-a' );
     eval { run3( \@cmd, \$text, \$output, \$error ) };
     $error = $@ if $@;
-    die "error running '" . join( " ", @cmd ) . "': " . $error if $error;
+    die q{error running '} . join( ' ', @cmd ) . q{': } . $error if $error;
 
     my ( @errors, %seen );
     foreach my $line ( split( "\n", $output ) ) {
@@ -38,7 +53,7 @@ sub validate_file {
             if ( !$seen{$original}++ ) {
                 my ($suggestions) = ( $remaining =~ /: (.*)/ );
                 if ( $suggestions && $self->suggest ) {
-                    push( @errors, sprintf( "%s (suggestions: %s)", $original, $suggestions ) );
+                    push( @errors, sprintf( '%s (suggestions: %s)', $original, $suggestions ) );
                 }
                 else {
                     push( @errors, $original );
@@ -65,7 +80,7 @@ Code::TidyAll::Plugin::PodSpell - Use Pod::Spell + ispell with tidyall
 
 =head1 VERSION
 
-version 0.55
+version 0.67
 
 =head1 SYNOPSIS
 
@@ -107,29 +122,33 @@ Install ispell from your package manager or from the link above.
 
 =head1 CONFIGURATION
 
-=over
+This plugin accepts the following configuration options:
 
-=item ispell_argv
+=head2 ispell_argv
 
-Arguments to pass to ispell. "-a" will always be passed, in order to parse the
-results.
+Arguments to pass to ispell. The "-a" flag will always be passed, in order to
+parse the results.
 
-=item ispell_cmd
+=head2 ispell_cmd
 
-Full path to ispell
+The path for the C<ispell> command. By default this is just C<ispell>, meaning
+that the user's C<PATH> will be searched for the command.
 
-=item suggest
+=head2 suggest
 
 If true, show suggestions next to misspelled words. Default is false.
 
-=back
-
 =head1 SUPPORT
 
-Bugs may be submitted through
+Bugs may be submitted at
 L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
-I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for Code-TidyAll can be found at
+L<https://github.com/houseabsolute/perl-code-tidyall>.
 
 =head1 AUTHORS
 
@@ -147,9 +166,12 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2016 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2017 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under the same
 terms as the Perl 5 programming language system itself.
 
+The full text of the license can be found in the F<LICENSE> file included with
+this distribution.
+
 =cut
