@@ -5,7 +5,7 @@ package Code::TidyAll::Util::Zglob;
 use strict;
 use warnings;
 
-our $VERSION = '0.55';
+our $VERSION = '0.67';
 
 use Exporter qw(import);
 
@@ -18,7 +18,12 @@ use constant debug => 0;
 
 sub zglobs_to_regex {
     my @globs = @_;
-    return @globs ? join( '|', map { "(?:" . zglob_to_regex($_) . ")" } @globs ) : qr/(?!)/;
+    return @globs
+        ? do {
+        my $re = join( '|', map { "(?:" . zglob_to_regex($_) . ")" } @globs );
+        qr/$re/;
+        }
+        : qr/(?!)/;
 }
 
 sub zglob_to_regex {
@@ -105,4 +110,57 @@ sub zglob_to_regex_string {
 }
 
 1;
+
+# ABSTRACT: Test::Glob hacked up to support "**/*"
+
 __END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Code::TidyAll::Util::Zglob - Test::Glob hacked up to support "**/*"
+
+=head1 VERSION
+
+version 0.67
+
+=head1 SUPPORT
+
+Bugs may be submitted at
+L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
+
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for Code-TidyAll can be found at
+L<https://github.com/houseabsolute/perl-code-tidyall>.
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 - 2017 by Jonathan Swartz.
+
+This is free software; you can redistribute it and/or modify it under the same
+terms as the Perl 5 programming language system itself.
+
+The full text of the license can be found in the F<LICENSE> file included with
+this distribution.
+
+=cut
